@@ -1,6 +1,3 @@
-from cosmoglobe.hub import sky_model
 from cosmoglobe.h5.model import model_from_chain
 from cosmoglobe.plot import plot, gnom, trace
 from cosmoglobe.h5.chain import Chain
-
-__all__ = ("Class",)
